@@ -68,7 +68,8 @@ class Table(object):
         if ensure:
             self._ensure_columns(row, types=types)
         res = self.database.executable.execute(self.table.insert(row))
-        return res.inserted_primary_key[0]
+        if len(res.inserted_primary_key) > 0:
+            return res.inserted_primary_key[0]
 
     def insert_many(self, rows, chunk_size=1000, ensure=True, types={}):
         """
@@ -125,18 +126,19 @@ class Table(object):
         if not keys or len(keys)==len(row):
             return False
         clause = [(u, row.get(u)) for u in keys]
-        """
-        Don't update the key itself, so remove any keys from the row dict
-        """
-        for key in keys:
-            if key in row.keys():
-                del row[key]
 
         if ensure:
             self._ensure_columns(row, types=types)
+
+        # Don't update the key itself, so remove any keys from the row dict
+        clean_row = row.copy()
+        for key in keys:
+            if key in clean_row.keys():
+                del clean_row[key]
+
         try:
             filters = self._args_to_clause(dict(clause))
-            stmt = self.table.update(filters, row)
+            stmt = self.table.update(filters, clean_row)
             rp = self.database.executable.execute(stmt)
             return rp.rowcount > 0
         except KeyError:
@@ -225,6 +227,22 @@ class Table(object):
         finally:
             self.database._release()
 
+    def drop_column(self, name):
+        """
+        Drop the column ``name``
+        ::
+
+            table.drop_column('created_at')
+        """
+        self._check_dropped()
+        self.database._acquire()
+        try:
+            if name in self.table.columns.keys():
+                col = self.table.columns[name]
+                col.drop()
+        finally:
+            self.database._release()
+
     def create_index(self, columns, name=None):
         """
         Create an index to speed up queries on a table. If no ``name`` is given a random name is created.
